==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/tests/InterfaceRepo/Latency_Test/Latency_Query_Client.h <==
// -*- C++ -*-
// Latency_Query_Client.h,v 1.3 2003/10/29 04:05:44 bala Exp

// ============================================================================
//
// = LIBRARY
//    TAO/orbsvcs/tests/InterfaceRepo
//
// = FILENAME
//    Latency_Query_Client.h
//
// = DESCRIPTION
//    This class tests the latency of queries made on the IFR.
//
// = AUTHOR
//    Jeff Parsons <parsons@isis-server.isis.vanderbilt.edu>
//
// ============================================================================

#if !defined (LATENCY_QUERY_CLIENT_H)
#define LATENCY_QUERY_CLIENT_H

#include "tao/IFR_Client/IFR_BasicC.h"
#include "tao/ORB.h"

class Latency_Query_Client
{
  // = TITLE
  //     Querying IFR Client Implementation
  //
  // = DESCRIPTION
  //     Class wrapper for a client which queries the Interface Repository.
public:
  Latency_Query_Client (void);
  // Constructor

  ~Latency_Query_Client (void);
  // Destructor

  int init (int argc,
            char *argv[]);
  // Initialize the ORB and get the IFR object reference.

  int run (void);
  // Execute test code.
private:
  int parse_args (int argc,
                  char *argv[]);
  // Process the command line arguments.

  int populate_ifr (ACE_ENV_SINGLE_ARG_DECL);
  // Put in something to query about.

private:
  CORBA::Boolean debug_;
  // Toggle debugging output.

  CORBA::Boolean do_dump_history_;
  // Toggle saving of dump history.

  CORBA::ULong iterations_;
  // Number of queries in a run.

  CORBA::ORB_var orb_;
  // Storage of the ORB reference.

  CORBA::Repository_var repo_;
  // Storage of the IFR reference.

//  CORBA::AliasDef_var tdef_;
  // Storage of the typedef definition that we will query.

  CORBA::AttributeDef_var attr_;
  // Storage of the attribute definition we will query.
};

#endif /* LATENCY_QUERY_CLIENT_H */

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/tests/InterfaceRepo/Latency_Test/Latency_Query_Client.h <==
// -*- C++ -*-
// Latency_Query_Client.h,v 1.4 2004/12/08 00:19:28 parsons Exp

// ============================================================================
//
// = LIBRARY
//    TAO/orbsvcs/tests/InterfaceRepo
//
// = FILENAME
//    Latency_Query_Client.h
//
// = DESCRIPTION
//    This class tests the latency of queries made on the IFR.
//
// = AUTHOR
//    Jeff Parsons <parsons@isis-server.isis.vanderbilt.edu>
//
// ============================================================================

#if !defined (LATENCY_QUERY_CLIENT_H)
#define LATENCY_QUERY_CLIENT_H

#include "tao/IFR_Client/IFR_BasicC.h"
#include "tao/ORB.h"

class Latency_Query_Client
{
  // = TITLE
  //     Querying IFR Client Implementation
  //
  // = DESCRIPTION
  //     Class wrapper for a client which queries the Interface Repository.
public:
  Latency_Query_Client (void);
  // Constructor

  ~Latency_Query_Client (void);
  // Destructor

  int init (int argc,
            char *argv[]);
  // Initialize the ORB and get the IFR object reference.

  int run (void);
  // Execute test code.
private:
  int parse_args (int argc,
                  char *argv[]);
  // Process the command line arguments.

  int populate_ifr (ACE_ENV_SINGLE_ARG_DECL);
  // Put in something to query about.

private:
  bool debug_;
  // Toggle debugging output.

  bool do_dump_history_;
  // Toggle saving of dump history.

  CORBA::ULong iterations_;
  // Number of queries in a run.

  CORBA::ORB_var orb_;
  // Storage of the ORB reference.

  CORBA::Repository_var repo_;
  // Storage of the IFR reference.

//  CORBA::AliasDef_var tdef_;
  // Storage of the typedef definition that we will query.

  CORBA::AttributeDef_var attr_;
  // Storage of the attribute definition we will query.
};

#endif /* LATENCY_QUERY_CLIENT_H */
